package com.doc.biz.controller;

import com.doc.biz.domain.DocDir;
import com.doc.biz.domain.DocInfo;
import com.doc.biz.service.IDocDirService;
import com.doc.biz.service.IDocInfoService;
import com.doc.common.annotation.Log;
import com.doc.common.core.controller.BaseController;
import com.doc.common.core.domain.AjaxResult;
import com.doc.common.enums.BusinessType;
import com.doc.common.utils.SecurityUtils;
import com.doc.common.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 文档目录管理Controller
 *
 * @author wukai
 * @date 2023-08-15
 */
@Api(tags = "文档目录管理")
@RestController
@RequestMapping("/biz/dir")
public class DocDirController extends BaseController {
    @Resource
    private IDocDirService docDirService;
    @Resource
    private IDocInfoService docInfoService;

    /**
     * 查询文档目录管理列表
     */
    @ApiOperation("查询目录列表")
    //@PreAuthorize("@ss.hasPermi('biz:dir:list')")
    @GetMapping("/list")
    public AjaxResult list(DocDir docDir) {
        List<DocDir> list = docDirService.selectDocDirList(docDir);
        return success(list);
    }

    /**
     * 导出文档目录管理列表
     */
//    @ApiOperation("导出文档目录管理列表")
    //@PreAuthorize("@ss.hasPermi('biz:dir:export')")
    @Log(title = "文档目录管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DocDir docDir) {
        List<DocDir> list = docDirService.selectDocDirList(docDir);
        ExcelUtil<DocDir> util = new ExcelUtil<DocDir>(DocDir.class);
        util.exportExcel(response, list, "文档目录管理数据");
    }

    /**
     * 获取文档目录管理详细信息
     */
//    @ApiOperation("获取文档目录管理详细信息")
    //@PreAuthorize("@ss.hasPermi('biz:dir:query')")
    @GetMapping(value = "/{dirId}")
    public AjaxResult getInfo(@PathVariable("dirId") Long dirId) {
        return success(docDirService.selectDocDirByDirId(dirId));
    }

    /**
     * 新建目录
     */
    @ApiOperation("新建目录")
    //@PreAuthorize("@ss.hasPermi('biz:dir:add')")
    @Log(title = "文档目录管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DocDir docDir) {
        return toAjax(docDirService.insertDocDir(docDir));
    }

    /**
     * 重命名
     */
    @ApiOperation("重命名")
    @Log(title = "文档目录管理", businessType = BusinessType.UPDATE)
    @GetMapping("/rename")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "dirId", value = "目录ID", required = true),
            @ApiImplicitParam(name = "name", value = "新目录名", required = true)
    })
    public AjaxResult rename(Long dirId, String name) {
        DocDir docDir = new DocDir();
        docDir.setDirId(dirId);
        docDir.setDirName(name);
        docDir.setUpdateBy(SecurityUtils.getUsername());

        return toAjax(docDirService.updateDocDir(docDir));
    }

    /**
     * 修改文档目录管理
     */
//    @ApiOperation("修改文档目录管理")
    //@PreAuthorize("@ss.hasPermi('biz:dir:edit')")
    @Log(title = "文档目录管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DocDir docDir) {
        return toAjax(docDirService.updateDocDir(docDir));
    }


    /**
     * 删除文档目录管理
     */
    @ApiOperation("删除目录")
    //@PreAuthorize("@ss.hasPermi('biz:dir:remove')")
    @Log(title = "文档目录管理", businessType = BusinessType.DELETE)
    @DeleteMapping("/{dirId}")
    public AjaxResult remove(@PathVariable Long dirId) {
        DocDir dir = new DocDir();
        dir.setParentId(dirId);
        List list = docDirService.selectDocDirList(dir);
        if (list.size() > 0) {
            return error("目录不为空，无法删除!");
        }
        DocInfo info = new DocInfo();
        info.setDirId(dirId);
        list = docInfoService.selectDocInfoList(info);
        if (list.size() > 0) {
            return error("目录不为空，无法删除!");
        }
        return toAjax(docDirService.deleteDocDirByDirId(dirId));
    }
}
